changeset 1986:cf1622476eb7 libavformat

typos/grammar
author diego
date Sat, 07 Apr 2007 14:09:20 +0000
parents b5e15030d788
children 1d9048ba2ce3
files avformat.h http.c mtv.c
diffstat 3 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/http.c	Fri Apr 06 18:29:27 2007 +0000
+++ b/http.c	Sat Apr 07 14:09:20 2007 +0000
@@ -24,8 +24,8 @@
 
 #include "base64.h"
 
-/* XXX: POST protocol is not completly implemented because ffmpeg use
-   only a subset of it */
+/* XXX: POST protocol is not completely implemented because ffmpeg uses
+   only a subset of it. */
 
 //#define DEBUG
 
--- a/mtv.c	Fri Apr 06 18:29:27 2007 +0000
+++ b/mtv.c	Sat Apr 07 14:09:20 2007 +0000
@@ -89,7 +89,7 @@
 
     /* FIXME Add sanity check here */
 
-    /* first packet is allways audio*/
+    /* first packet is always audio*/
 
     mtv->audio_packet_count = 1;
--- a/avformat.h	Fri Apr 06 18:29:27 2007 +0000
+++ b/avformat.h	Sat Apr 07 14:09:20 2007 +0000
@@ -204,7 +204,7 @@
     int (*read_probe)(AVProbeData *);
     /** read the format header and initialize the AVFormatContext
        structure. Return 0 if OK. 'ap' if non NULL contains
-       additionnal paramters. Only used in raw format right
+       additional paramters. Only used in raw format right
        now. 'av_new_stream' should be called to create new streams.  */
     int (*read_header)(struct AVFormatContext *,
                        AVFormatParameters *ap);
@@ -526,7 +526,7 @@
  * @param filename filename to open.
  * @param fmt if non NULL, force the file format to use
  * @param buf_size optional buffer size (zero if default is OK)
  * @param ap additionnal parameters needed when opening the file (NULL if default)
  * @return 0 if OK. AVERROR_xxx otherwise.
  */
 int av_open_input_file(AVFormatContext **ic_ptr, const char *filename,
@@ -526,7 +526,7 @@
  * @param fmt if non NULL, force the file format to use
  * @param buf_size optional buffer size (zero if default is OK)
- * @param ap additionnal parameters needed when opening the file (NULL if default)
+ * @param ap additional parameters needed when opening the file (NULL if default)
  * @return 0 if OK. AVERROR_xxx otherwise.
  */